@@ -10,40 +10,17 @@ TILE_LAYER_OPTIONS = {
 }
 
 
-@hookimpl
-def extra_css_urls(database, table, columns, view_name, datasette):
-    if not has_columns(database, table, columns, view_name, datasette):
-        return []
-    return [
-        {
-            "url": "https://unpkg.com/leaflet@1.5.1/dist/leaflet.css",
-            "sri": "sha512-xwE/Az9zrjBIphAcBb3F6JVqxf46+CDLwfLMHloNu6KEQCAWi6HcDUbeOfBIptF7tcCzusKFjFw2yuvEpDL9wQ==",
-        },
-        {
-            "url": "https://unpkg.com/leaflet.markercluster@1.4.1/dist/MarkerCluster.css",
-            "sri": "sha384-lPzjPsFQL6te2x+VxmV6q1DpRxpRk0tmnl2cpwAO5y04ESyc752tnEWPKDfl1olr",
-        },
-        {
-            "url": "https://unpkg.com/leaflet.markercluster@1.4.1/dist/MarkerCluster.Default.css",
-            "sri": "sha384-5kMSQJ6S4Qj5i09mtMNrWpSi8iXw230pKU76xTmrpezGnNJQzj0NzXjQLLg+jE7k",
-        },
-    ]
-
-
 @hookimpl
 def extra_js_urls(database, table, columns, view_name, datasette):
     if not has_columns(database, table, columns, view_name, datasette):
         return []
     return [
         {
-            "url": "https://unpkg.com/leaflet@1.5.1/dist/leaflet.js",
-            "sri": "sha512-GffPMF3RvMeYyc1LWMHtK8EbPv0iNZ8/oTtHPx9/cc2ILxQ+u905qIwdpULaqDkyBKgOaB57QTMg7ztg8Jm2Og==",
-        },
-        {
-            "url": "https://unpkg.com/leaflet.markercluster@1.4.1/dist/leaflet.markercluster-src.js",
-            "sri": "sha384-N9K+COcUk7tr9O2uHZVp6jl7ueGhWsT+LUKUhd/VpA0svQrQMGArhY8r/u/Pkwih",
-        },
-        "/-/static-plugins/datasette_cluster_map/datasette-cluster-map.js",
+            "url": datasette.urls.static_plugins(
+                "datasette-cluster-map", "datasette-cluster-map.js"
+            ),
+            "module": True,
+        }
     ]
 
 
@@ -74,6 +51,20 @@ def extra_body_script(database, table, columns, view_name, datasette):
                     key.upper(), json.dumps(value)
                 )
             )
+    js.append("window.datasette = window.datasette || {};")
+    js.append(
+        "datasette.cluster_map = {\n"
+        + "    MARKERCLUSTER_URL: '{}',\n".format(
+            datasette.urls.static_plugins(
+                "datasette-cluster-map", "leaflet.markercluster.min.js"
+            )
+        )
+        + "    MARKERCLUSTER_CSS_URL: '{}'\n}};".format(
+            datasette.urls.static_plugins(
+                "datasette-cluster-map", "leaflet.markercluster.css"
+            )
+        )
+    )
     return "\n".join(js)
 
 
